==> deeperseek-0.1.tar.gz: deeperseek-0.1/README.md <==
# DeeperSeek  
[![Downloads](https://static.pepy.tech/badge/deeperseek)](https://pepy.tech/project/deeperseek)  
[![PyPi](https://img.shields.io/pypi/v/DeeperSeek.svg)](https://pypi.python.org/pypi/DeeperSeek)  
[![License](https://img.shields.io/github/license/Sxvxgee/DeeperSeek.svg?color=green)](https://github.com/Sxvxgee/DeeperSeek/blob/main/LICENSE)  

DeeperSeek is a Python library for using the DeepSeek website as an alternative API to the DeepSeek paid API.

DeeperSeek makes it easy to send messages and receive responses. DeeperSeek can also do a wide range of things such as supporting multiple login methods, seamless and easy process when switching accounts, bypassing Cloudflare protection, running in headless mode, supporting DeepThink and search-enhanced responses, and much more.

![Preview](https://raw.githubusercontent.com/Sxvxgee/DeeperSeek/main/docs/assets/preview.png)  

## Compatibility  

DeeperSeek works on Windows, Linux, and macOS. It also supports Google Colab and other headless Linux servers. DeeperSeek requires Python 3.8 or later.

## Features  

-   [x] Automates message sending and response retrieval in DeepSeek
-   [x] Supports login via token or email/password authentication
-   [x] Allows regenerating responses
-   [x] Enables session management (reset chat, log out, retrieve token)
-   [x] Supports bypassing Cloudflare protection
-   [x] Headless mode for running on servers or automation setups
-   [x] Customizable browser arguments for better control over execution
-   [x] Supports "DeepThink" and search-enhanced responses
-   [x] Proxy support for enhanced security
-   [x] Detailed logging with customizable verbosity

## Documentation  

You can find the documentation [here](https://github.com/Sxvxgee/DeeperSeek/blob/main/docs/README.md).  

## Changelog  

You can find the changelog [here](https://github.com/Sxvxgee/DeeperSeek/blob/main/CHANGELOG.md).  

## Disclaimer  

- This project is not affiliated with DeepSeek in any way. Use at your own risk. I am not responsible for any damage caused by this project.  

## License  

This project is licensed under the GPLv3 License - see the [LICENSE](LICENSE) file for details.  

---

Let me know if you want any further refinements! 😊

==> deeperseek-0.1.2.tar.gz: deeperseek-0.1.2/README.md <==
# DeeperSeek  
[![Downloads](https://static.pepy.tech/badge/deeperseek)](https://pepy.tech/project/deeperseek)  
[![PyPi](https://img.shields.io/pypi/v/DeeperSeek.svg)](https://pypi.python.org/pypi/DeeperSeek)  
[![License](https://img.shields.io/github/license/theAbdoSabbagh/DeeperSeek.svg?color=green)](https://github.com/theAbdoSabbagh/DeeperSeek/blob/main/LICENSE)  

DeeperSeek is a Python library for using the DeepSeek website as an alternative API to the DeepSeek paid API.

DeeperSeek makes it easy to send messages and receive responses. DeeperSeek can also do a wide range of things such as supporting multiple login methods, seamless and easy process when switching accounts, bypassing Cloudflare protection, running in headless mode, supporting DeepThink and search-enhanced responses, and much more.

![Preview](https://raw.githubusercontent.com/theAbdoSabbagh/DeeperSeek/main/docs/assets/preview.png)  

## Compatibility  

DeeperSeek works on Windows, Linux, and macOS. It also supports Google Colab and other headless Linux servers. DeeperSeek requires Python 3.8 or later.

## Features  

-   [x] Automates message sending and response retrieval in DeepSeek
-   [x] Supports login via token or email/password authentication
-   [x] Allows regenerating responses
-   [x] Enables session management (reset chat, log out, retrieve token)
-   [x] Supports bypassing Cloudflare protection
-   [x] Headless mode for running on servers or automation setups
-   [x] Customizable browser arguments for better control over execution
-   [x] Supports "DeepThink" and search-enhanced responses
-   [x] Proxy support for enhanced security
-   [x] Detailed logging with customizable verbosity

## Documentation  

You can find the documentation [here](https://github.com/theAbdoSabbagh/DeeperSeek/blob/main/docs/README.md).  

## Changelog  

You can find the changelog [here](https://github.com/theAbdoSabbagh/DeeperSeek/blob/main/CHANGELOG.md).  

## Disclaimer  

- This project is not affiliated with DeepSeek in any way. Use at your own risk. I am not responsible for any damage caused by this project.  

## License  

This project is licensed under the GPLv3 License - see the [LICENSE](LICENSE) file for details.  

## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=theAbdoSabbagh/DeeperSeek&type=Date)](https://star-history.com/#theAbdoSabbagh/DeeperSeek&Date)
